@@ -1,8 +1,22 @@
 /*
- * Equalizer.h
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 26 июля 2016 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 26 июля 2016 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef CORE_FILTERS_EQUALIZER_H_
@@ -22,6 +36,9 @@ namespace lsp
         EQM_FFT     // Approximation of the frequency chart in the frequency range
     };
 
+    /**
+     * Set of multiple controllable sequential filters combined into one managed object
+     */
     class Equalizer
     {
         private:
@@ -60,59 +77,64 @@ namespace lsp
             explicit Equalizer();
             ~Equalizer();
 
-        public:
+            /**
+             * Construct the object being part of memory chunk
+             */
+            void                construct();
+
             /** Initialize equalizer
              *
              * @param filters number of filters
              * @param conv_rank convolution size rank
              * @return true on success
              */
-            bool init(size_t filters, size_t conv_rank);
+            bool                init(size_t filters, size_t conv_rank);
 
             /** Destroy equalizer
              *
              */
-            void destroy();
+            void                destroy();
 
+        public:
             /** Update filter parameters
              * @param id ID of the filter
              * @param params  filter parameters
              * @return true on success
              */
-            bool set_params(size_t id, const filter_params_t *params);
+            bool                set_params(size_t id, const filter_params_t *params);
 
             /** Get filter parameters
              * @param id ID of the filter
              * @param params  filter parameters
              * @return true on success
              */
-            bool get_params(size_t id, filter_params_t *params);
+            bool                get_params(size_t id, filter_params_t *params);
 
             /** Check that filter is active
              *
              * @param id ID of filter
              * @return true if filter is active
              */
-            inline bool filter_active(size_t id) const { return (id < nFilters) ? vFilters[id].active() : false; }
+            inline bool         filter_active(size_t id) const { return (id < nFilters) ? vFilters[id].active() : false; }
 
             /** Check that filter is inactive
              *
              * @param id ID of filter
              * @return true if filter is inactive
              */
-            inline bool filter_inactive(size_t id) const { return (id < nFilters) ? vFilters[id].inactive() : false; }
+            inline bool         filter_inactive(size_t id) const { return (id < nFilters) ? vFilters[id].inactive() : false; }
 
             /** Set equalizer mode
              *
              * @param mode equalizer mode
              */
-            void set_mode(equalizer_mode_t mode);
+            void                set_mode(equalizer_mode_t mode);
 
             /** Set sample rate
              *
              * @param sr sample rate
              */
-            void set_sample_rate(size_t sr);
+            void                set_sample_rate(size_t sr);
 
             /** Get equalizer mode
              *
@@ -124,9 +146,9 @@ namespace lsp
              *
              * @return equalizer latency
              */
-            inline size_t get_latency() const { return nLatency; }
+            inline size_t       get_latency() const { return nLatency; }
 
-            /** Get frequency chart of the filter
+            /** Get frequency chart of the specific filter
              *
              * @param id ID of the filter
              * @param re real part of the frequency chart
@@ -135,9 +157,9 @@ namespace lsp
              * @param count number of dots for the chart
              * @return status of operation
              */
-            bool freq_chart(size_t id, float *re, float *im, const float *f, size_t count);
+            bool                freq_chart(size_t id, float *re, float *im, const float *f, size_t count);
 
-            /** Get frequency chart of the filter
+            /** Get frequency chart of the specific filter
              *
              * @param id ID of the filter
              * @param c complex numbers that contain the filter transfer function
@@ -145,7 +167,24 @@ namespace lsp
              * @param count number of points
              * @return status of operation
              */
-            bool freq_chart(size_t id, float *c, const float *f, size_t count);
+            bool                freq_chart(size_t id, float *c, const float *f, size_t count);
+
+            /**
+             * Get frequency chart of the whole equalizer
+             * @param re real part of the frequency chart
+             * @param im imaginary part of the frequency chart
+             * @param f frequencies to calculate value
+             * @param count number of dots for the chart
+             */
+            void                freq_chart(float *re, float *im, const float *f, size_t count);
+
+            /**
+             * Get frequency chart of the whole equalizer
+             * @param c complex numbers that contain the filter transfer function
+             * @param f frequencies to calculate filter transfer function
+             * @param count number of points
+             */
+            void                freq_chart(float *c, const float *f, size_t count);
 
             /** Process the signal
              *
@@ -153,13 +192,13 @@ namespace lsp
              * @param in input signal samples
              * @param samples number of samples to process
              */
-            void process(float *out, const float *in, size_t samples);
+            void                process(float *out, const float *in, size_t samples);
 
             /**
              * Dump the state
              * @param dumper dumper
              */
-            void dump(IStateDumper *v) const;
+            void                dump(IStateDumper *v) const;
     };
 
 } /* namespace lsp */
