@@ -1,8 +1,22 @@
 /*
- * metadata.h
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 28 сент. 2015 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 28 сент. 2015 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef METADATA_METADATA_H_
@@ -29,6 +43,7 @@
 #define LSP_LADSPA_BASE                                 0x4C5350
 #define LSP_DONATION_URI1                               "https://salt.bountysource.com/teams/" LSP_ARTIFACT_ID
 #define LSP_DONATION_URI2                               "https://liberapay.com/sadko4u/donate"
+#define LSP_PLUGINS_MAILBOX                             "lsp.plugin@gmail.com"
 #define LSP_DOWNLOAD_URI                                LSP_BASE_URI "?page=download"
 
 // Different LV2 UI classes for different platforms
@@ -248,16 +263,18 @@ namespace lsp
         PGR_REAR_LEFT,
         PGR_REAR_RIGHT,
         PGR_RIGHT,
-        PGR_SIDE,
         PGR_SIDE_LEFT,
-        PGR_SIDE_RIGHT
+        PGR_SIDE_RIGHT,
+        PGR_MS_SIDE,
+        PGR_MS_MIDDLE
     };
 
     enum port_group_flags_t
     {
         PGF_IN          = (0 << 0),     // Input group
         PGF_OUT         = (1 << 0),     // Output group
-        PGF_SIDECHAIN   = (1 << 1)      // Sidechain
+        PGF_SIDECHAIN   = (1 << 1),     // Sidechain
+        PGF_MAIN        = (1 << 2),     // Main input/output group
     };
 
     typedef struct port_group_item_t
