@@ -1,8 +1,22 @@
 /*
- * ctl.h
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 15 июн. 2017 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 15 июн. 2017 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef UI_CTL_CTL_H_
@@ -32,7 +46,6 @@ namespace lsp
 
             WC_ALIGN,
             WC_AXIS,
-            WC_BASIS,
             WC_BODY,
             WC_BOX,
             WC_BUTTON,
@@ -333,7 +346,6 @@ namespace lsp
 #include <ui/ctl/CtlGraph.h>
 #include <ui/ctl/CtlAxis.h>
 #include <ui/ctl/CtlCenter.h>
-#include <ui/ctl/CtlBasis.h>
 #include <ui/ctl/CtlMarker.h>
 #include <ui/ctl/CtlMesh.h>
 #include <ui/ctl/CtlDot.h>
