@@ -1,8 +1,22 @@
 /*
- * metadata.cpp
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 16 окт. 2015 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 16 окт. 2015 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <core/types.h>
@@ -71,39 +85,32 @@ namespace lsp
 
     const port_group_t mono_plugin_port_groups[] =
     {
-        { "mono_in",        "Mono Input",       GRP_MONO,       PGF_IN,     mono_in_group_ports         },
-        { "mono_out",       "Mono Output",      GRP_MONO,       PGF_OUT,    mono_out_group_ports        },
-        { NULL, NULL }
+        MAIN_MONO_PORT_GROUPS,
+        PORT_GROUPS_END
     };
 
     const port_group_t mono_plugin_sidechain_port_groups[] =
     {
-        { "mono_in",        "Mono Input",       GRP_MONO,       PGF_IN,     mono_in_group_ports         },
-        { "mono_out",       "Mono Output",      GRP_MONO,       PGF_OUT,    mono_out_group_ports        },
-        { "sidechain_in",   "Sidechain Input",  GRP_MONO,       PGF_IN | PGF_SIDECHAIN,     mono_sidechain_group_ports, "mono_in"  },
-        { NULL, NULL }
+        MAIN_SC_MONO_PORT_GROUPS,
+        PORT_GROUPS_END
     };
 
     const port_group_t mono_to_stereo_plugin_port_groups[] =
     {
-        { "mono_in",        "Mono Input",       GRP_MONO,       PGF_IN,     mono_in_group_ports         },
-        { "stereo_out",     "Stereo Output",    GRP_STEREO,     PGF_OUT,    stereo_out_group_ports      },
-        { NULL, NULL }
+        MAIN_MONO2STEREO_PORT_GROUPS,
+        PORT_GROUPS_END
     };
 
     const port_group_t stereo_plugin_port_groups[] =
     {
-        { "stereo_in",      "Stereo Input",     GRP_STEREO,     PGF_IN,     stereo_in_group_ports       },
-        { "stereo_out",     "Stereo Output",    GRP_STEREO,     PGF_OUT,    stereo_out_group_ports      },
-        { NULL, NULL }
+        MAIN_STEREO_PORT_GROUPS,
+        PORT_GROUPS_END
     };
 
     const port_group_t stereo_plugin_sidechain_port_groups[] =
     {
-        { "stereo_in",      "Stereo Input",     GRP_STEREO,     PGF_IN,     stereo_in_group_ports       },
-        { "stereo_out",     "Stereo Output",    GRP_STEREO,     PGF_OUT,    stereo_out_group_ports      },
-        { "sidechain_in",   "Sidechain Input",  GRP_STEREO,     PGF_IN | PGF_SIDECHAIN,     stereo_sidechain_group_portss, "stereo_in" },
-        { NULL, NULL }
+        MAIN_SC_STEREO_PORT_GROUPS,
+        PORT_GROUPS_END
     };
 
     //-------------------------------------------------------------------------
