@@ -1,8 +1,22 @@
 /*
- * plugin_ui.cpp
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 20 окт. 2015 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 20 окт. 2015 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <core/debug.h>
@@ -770,13 +784,6 @@ namespace lsp
                 vWidgets.add(cnt);
                 return new CtlCenter(this, cnt);
             }
-            case WC_BASIS:
-            {
-                LSPBasis *basis = new LSPBasis(&sDisplay);
-                basis->init();
-                vWidgets.add(basis);
-                return new CtlBasis(this, basis);
-            }
             case WC_MARKER:
             {
                 LSPMarker *mark = new LSPMarker(&sDisplay);
